function movie_example(file)
%
% file is a string of the ROMS output (history) file
%
%        
% This is an example m-file for plotting
% a movie of the model results
%
%
%% Load data

% Pull out time and spatial dimensions
time=ncread(file,'ocean_time');
    %Convert time from seconds into days
    time=time/60/60/24;
    % Reference time to first timestep
    time=time-time(1);
y=ncread(file,'y_rho');
x=ncread(file,'x_rho');
    %Convert from m to km
    x=x./1000;
    y=y./1000;
h=ncread(file,'h');
zw=roms_depths(file,'w');
    dz=zw(:,:,2:end,:)-zw(:,:,1:end-1,:);
    clear zw
    
% Pull out the variables of interest
%    Salinity
salt=ncread(file,'salt',[1 1 13 1],[Inf Inf 1 Inf]); 
%    Depth-averaged currents
[u2,v2]=interp_roms_uv_depthavg(file,[1 1 1],[Inf Inf Inf]);
%    Seabed deposit: Add river sediment classes together, 
%                    and depth integrate in kg/m2
mmass1=ncread(file,'mudmass_01');
mmass2=ncread(file,'mudmass_02');
mmass=mmass1+mmass2;
    mmass=squeeze(sum(mmass,3));
    mmass=mmass-repmat(mmass(:,:,1),[1,1,size(mmass,3)]);
clear mmass1 mmass2
%     Suspended sediment: multiply SSC (kg/m3) by dz(m) to get kg/m2
mud1=ncread(file,'mud_01');
mud2=ncread(file,'mud_02');
mud=(mud1+mud2).*dz; % kg/m2
    clear mud1 mud2
    mud=squeeze(sum(mud,3));
    
%%  Plot 


for TT=1:length(time)

figure(1)
clf
set(0,'defaultaxesfontsize',12)
set(gcf,'color','w')
x_lim=[min(x(:)) 50];
y_lim=[20 max(y(:))];

% Plot salinity for timestep TT and vertical level ZZ
plan1=axes('position',[0.13 .2 .25 .65]);
c_axis=[20 36];        
pcolor(x,y,squeeze(salt(:,:,end,TT)));
caxis(c_axis); 
title('Salinity');
ylabel('Along-Shore Distance (km)');
shading flat;
axis equal; set(gca,'color','w');axis tight;
xlim(x_lim);
ylim(y_lim);
hold on ;
psliceuv(x,y,squeeze(u2(:,:,TT)+sqrt(-1).*v2(:,:,TT)),5,30,'b');
leg1=pclegen2([20:2:36],[.05 -.2 .6 .03]);
text(35,-10,'psu','fontsize',12);

% Plot depth-integrated SSC (kg/m2)
% for timestep TT and vertical level ZZ
plan2=axes('position',[0.13+.3 .2 .25 .65]);
c_axis2=[0 max(mud(:))];        
pcolor(x,y,squeeze(mud(:,:,TT)));
caxis(c_axis2); 
shading flat;
axis equal; set(gca,'color','w');axis tight;
xlim(x_lim);
ylim(y_lim);
set(gca,'yticklabel',' ');
xlabel('Across-Shore Distance (km)');
title('SSC');
leg2=pclegen2([0:max(mud(:))/9:max(mud(:))],[.05 -.2 .6 .03]);
text(35,-10,'kg m^-^2','fontsize',12);

% Plot deposited sediment (kg /m2) 
% for timestep TT and vertical level ZZ
plan3=axes('position',[0.13+.6 .2 .25 .65]);
c_axis3=[0 max(mmass(:))];        
pcolor(x,y,squeeze(mmass(:,:,TT)));
caxis(c_axis3); 
shading flat;
axis equal; set(gca,'color','w');axis tight;
xlim(x_lim);
ylim(y_lim);
set(gca,'yticklabel',' ');
title('Deposit');
hold on;
[cc,hh]=contour(x,y,h,[20:20:max(h(:))],'color',[1 1 1]*.8);
clabel(cc,hh);
caxis(c_axis3);
leg3=pclegen2([0:max(mmass(:))/9:max(mmass(:))],[.05 -.2 .6 .03]);
text(35,-10,'kg m^-^2','fontsize',12);
cmap=colormap('hot');
colormap(cmap(end:-1:1,:));

%Plot title and model time
plan4=axes('position',[0 0 1 1]);
set(gca,'color','none');
text(.4,.95,sprintf('Model Day %1.2f',time(TT)),'fontsize',16,'fontweight','bold');
set(gca,'xtick',[-1 1.2]);
set(gca,'ytick',[-1 1.2]);

pause(.1)
end
end