function profile_example(file,TT)
% This is an example for plotting
% a vertical profile of sediment concentrations
%
%Input:
% file is a string of the ROMS output (history) file
% TT is the timestep
%
% e.g. pslice_example(file,11)
%      This plots the profiles at timestep 11
%      For the riverplume model, 
%
%% Load data

%Choose which grid cell to get data for
XX=8;  %choose 8th column of the grid
YY=50; %60;  %choose 60th row of the grid

% Pull out time and spatial dimensions
time=ncread(file,'ocean_time');
    %Convert time from seconds into days
    time=time/60/60/24;
    % Reference time to first timestep
    time=time-time(1);
h=ncread(file,'h',[XX YY],[1 1]);
z=roms_depths(file,'rho');
   z=squeeze(z(XX,YY,:,:));
   
% Pull out the variable of interest
salt=squeeze(ncread(file,'salt',[XX YY 1 1],[1 1 Inf Inf])); 
mud1=squeeze(ncread(file,'mud_01',[XX YY 1 1],[1 1 Inf Inf])); 
mud2=squeeze(ncread(file,'mud_02',[XX YY 1 1],[1 1 Inf Inf])); 
mud3=squeeze(ncread(file,'mud_03',[XX YY 1 1],[1 1 Inf Inf])); 

% Interpolate u and v to rho points
[u,v]=interp_roms_uv2(file,[XX YY 1 1],[1 1 Inf Inf]);
vel=squeeze(sqrt(u.*u+v.*v));
%%  Plot profile of sediment concentrations near river mouth

figure
set(0,'defaultaxesfontsize',16)
x_axis_vel=[0 max(vel(:))];
x_axis=[1e-7 1]; %[0 max(mud1(:)+mud2(:)+mud3(:))];
x_axis_salt=[min(salt(:)) max(salt(:))];

% Plot salinity for timestep TT and across-shore row YY
clf
set(gcf,'color','w')

subplot(1,3,1)
plot(vel(:,TT),squeeze(z(:,TT)),'k-x','linewidth',2)
xlim(x_axis_vel)
ylim([-1*h 0])
xlabel('Velocity (m s^-^1)')
ylabel('Water Depth (m)')
%set(gca,'yscale','log')
set(gca,'xaxislocation','top')

subplot(1,3,2)
plot(salt(:,TT),squeeze(z(:,TT)),'k-x','linewidth',2)
xlim(x_axis_salt)
ylim([-1*h 0])
xlabel('Salinity (psu)')
%ylabel('Water Depth (m)')
%set(gca,'yscale','log')
set(gca,'yticklabel',' ')
title(sprintf('Model Day %1.2f',time(TT)),'fontsize',16)
set(gca,'xaxislocation','top')

subplot(1,3,3)
%plot(squeeze(mud1(:,TT)),squeeze(z(:,TT)),'b-','linewidth',2)
%hold on
%plot(squeeze(mud2(:,TT)),squeeze(z(:,TT)),'b--','linewidth',2)
%plot(squeeze(mud3(:,TT)),squeeze(z(:,TT)),'b-.','linewidth',2)
semilogx(squeeze(mud1(:,TT)+mud2(:,TT)+mud3(:,TT)),squeeze(z(:,TT)),'k-x','linewidth',2)
xlim(x_axis)
ylim([-1*h 0])
xlabel('SSC (g L^-^1)')
%ylabel('Water Depth (m)')
set(gca,'yticklabel',' ')
%set(gca,'xscale','log')
set(gca,'xtick',[1e-5 1])
set(gca,'xaxislocation','top')

pause(0.1)
end