function pslice_example(file, TT, ZZ)
%
% This is an example m-file for plotting
% spatial maps of salinity
%
%
% file is a string of the ROMS output (history) file
% TT is the timestep
% ZZ is the vertical layer (increasing from 1, which is the seabed)
%        
% e.g. pslice_example(file,11,20)
%      This plots the river plume at timestep 11
%      for the 20th vertical layer.
%      For the riverplume model, the 20th layer is the surface layer)
%
%% Load data

% Pull out time and spatial dimensions
time=ncread(file,'ocean_time');
    %Convert time from seconds into days
    time=time/60/60/24;
    % Reference time to first timestep
    time=time-time(1);
y=ncread(file,'y_rho');
x=ncread(file,'x_rho');
    %Convert from m to km
    x=x./1000;
    y=y./1000;
h=ncread(file,'h');

% Pull out the variable of interest
salt=ncread(file,'salt',[1 1 ZZ TT],[Inf Inf 1 1]); 
%Interpolate u and v to rho points
[u2,v2]=interp_roms_uv2(file,[1 1 ZZ TT],[Inf Inf 1 1]);
%%  Plot 
figure
clf
set(0,'defaultaxesfontsize',12)
set(gcf,'color','w')

% Plot salinity for timestep TT and vertical level ZZ
c_axis=[20 36];        
pcolor(x,y,salt);caxis(c_axis); 
title(sprintf('Salinity (psu), Model Day %1.2f',time(TT)));
%xlim([5 50])
%ylim([60 190])
xlabel('Across-Shore Distance (km)');
ylabel('Along-Shore Distance (km)');
shading flat
%text(16,10,'40 m','rotation',90)
%text(36,10,'80 m','rotation',90)
colorbar
% add depth contours
hold on
[cc,hh]=contour(x,y,h,[20:20:max(h(:))],'color',[1 1 1].*0);
% add current velocity vectors
hold on 
psliceuv(x,y,squeeze(u2+sqrt(-1).*v2),5,30,'w');

axis equal;
axis tight;

end
