function pslice_example_bed(file, TT)
% This is an example for plotting a spatial map of deposited sediment
%
%
%Input:
% file is a string of the ROMS output (history) file
% TT is the timestep
%
% e.g. pslice_example_bed(file,11)
%      This plots the riverine deposit at timestep 11
%

%% Load data

% Pull out time and spatial dimensions
time=ncread(file,'ocean_time');
    %Convert time from seconds into days
    time=time/60/60/24;
    % Reference time to first timestep
    time=time-time(1);
y=ncread(file,'y_rho');
x=ncread(file,'x_rho');
    %Convert from m to km
    x=x./1000;
    y=y./1000;
h=ncread(file,'h');

% Pull out the variable of interest
%   i.e., the two classes of riverine sediment
mmass1=ncread(file,'mudmass_01');
mmass2=ncread(file,'mudmass_02');
%mmass3=ncread(file,'mudmass_03');

% Add river sediment classes together, and depth integrate
% in kg/m2
mmass=mmass1+mmass2; %+mmass3;
    mmass=squeeze(sum(mmass,3));
    mmass=mmass-repmat(mmass(:,:,1),[1,1,size(mmass,3)]);
    mmass=squeeze(mmass(:,:,TT));
%%  Plot figure
figure
clf
set(gcf,'color','w')
set(0,'defaultaxesfontsize',12)

pcolor(x,y,mmass)
title(sprintf('Deposit (kg m^-^2), Model Day %1.2f',time(TT)))
%xlim([min(x(:)) 30])
%ylim([40 100])
xlabel('Across-Shore Distance (km)')
ylabel('Along-Shore Distance (km)')
shading flat
box on
%axis equal; axis tight
colorbar
cmap=colormap('copper');
colormap(cmap(end:-1:1,:))

% add depth contours
hold on
[cc,hh]=contour(x,y,h,[20:20:max(h(:))],'k');
clabel(cc,hh)

%Set color scale
c_axis=[min(mmass(:)) max(mmass(:))];
caxis(c_axis)


end
