function z=roms_depths(ncf,vgrid,varargin)
%ROMS_DEPTHS Computes physical depths from ROMS files
%
%   z = roms_depths(fname,vgrid)
%   z = roms_depths(fname,gname)
%   z = roms_depths(fname,vgrid,gname)
%   z = roms_depths(...,[start,count,stride,hgrid])
%
%   fname - ROMS history file
%   vgrid - 'w' or 'rho'
%   gname - grid file name  (default: same as fname)
%
%   Start/count/stride base on 3-D zeta
%
%   Heavily modified from depths.m in Rutgers ROMS-toolbox

% $Id: roms_depths.m 53 2008-05-08 14:10:38Z jpaul $
%
% Edited by JMM, May 2014
%% Check arguments

if ~exist('vgrid','var') || isempty(vgrid), vgrid = 'rho'; end

gvArgs = varargin;
% Check if 2nd arg is a vgrid or a gname, or start
if ischar(vgrid)
    if ismember(vgrid,{'w','rho'})
        gname = ncf;
    else
        gname = vgrid;
        vgrid = 'rho';
    end
else
    gvArgs = [{vgrid} gvArgs];
    gname = ncf;
end

% Check 3rd argument.  If it's a string, it must be the vgrid:

if ~isempty(gvArgs) && ischar(gvArgs{1});
    gname = gvArgs{1};
    gvArgs(1) = [];
end

% Create gv2Args for 2D H.  Loop through gvArgs, eliminate 1st element of
% start/count/slice
% Do not do anything to 4th gvArg as it's the gridType.
gv2Args = gvArgs;

for ii=1:length(gv2Args)
    if ~isempty(gvArgs{ii}) && ii~=4
        gv2Args{ii} = gvArgs{ii}(end-[1 0]);
    end
end

% Check if we have 4-D args
gv3Args = gvArgs;

for ii=1:length(gv2Args)
    if ~isempty(gvArgs{ii}) && ii~=4 && length(gvArgs{ii})==4
        gv3Args{ii} = gvArgs{ii}([1 3 4]);
    end
end

%% Get h and zeta
%h    = nc_varget(gname,'h',gv2Args{:},'squeezeoff');
%zeta = nc_varget(ncf,'zeta',gv3Args{:},'squeezeoff');
%h    = nc_varget(gname,'h',gv2Args{:});
%zeta = nc_varget(ncf,'zeta',gv3Args{:});
h    = ncread(gname,'h');
   h=shiftdim(h,1);
zeta = ncread(ncf,'zeta');
   for tt=1:size(zeta,3)
       zeta2(tt,:,:)=shiftdim(zeta(:,:,tt),1);
   end
   zeta=zeta2;
%% Zeta will always be 3-D with squeezeoff, so we need to replicate h to match
sizeH = size(h);
sizeZeta = size(zeta);
h = repmat(shiftdim(h,-1),[sizeZeta(1) 1 1]);


%% Get s-coord parameters
[Cs,s,hc] = roms_getscoords(ncf,vgrid);


%%  Do the calculation
z = scoord2z(h,s,Cs,hc,zeta);

% Permute 1st 2 dimensions if necesary
rankZ = ndims(z);

if rankZ >=4
    z = permute(z,[2 1 3:rankZ]);
end

for tt=1:size(z,4), for zz=1:size(z,3)
    z2(tt,zz,:,:)=shiftdim(z(:,:,zz,tt),1);
end,end
z=z2;

end

