function z = scoord2z(h,s,Cs,hc,zeta)
% Returns z from s-coordinate parameters
% z = scoord2z(h,s,cs,hc,zeta)
% h,zeta, & hc must be same size
% cs and s must be same size
%
% Hc can be scalar
%

% $Id: scoord2z.m 78 2008-05-28 16:25:59Z jpaul $
% TODO: Check for more scalar arguments than just Hc

%% Check for scalar arguments

if ~exist('zeta','var')
    zeta = zeros(size(h));
end

if isscalar(hc)
    hc = hc* ones(size(zeta));
end

if isscalar(h)
    h = h * ones(size(zeta));
end

    

%% Make zeta,h,hc rows; cs, s,columns
szZeta  = size(zeta);
szCs    = size(Cs);
endSize = [szCs szZeta];

% One row vectors
zeta = zeta(:)';
h    = h(:)';
hc   = hc(:)';

% One column vectors
s    = s(:);
Cs   = Cs(:);

% Get sizes
nz = size(s,1);
nt = prod(szZeta)./numel(h);    % Use this form incase dimensions aren't consistant

%% Get z-levels
% This matches ROMS set_depths.F
cff1 = s*hc + Cs*(h-hc);
cff2 = s*(hc./h) + Cs*((h-hc)./h)+1;

% cff1 & cff2 are now 2-d: nz x [nx ny]
% zeta is 1-D : 1 x [nt nx ny]
z = repmat(cff1,1,nt) + repmat(cff2,1,nt).*repmat(zeta,nz,1);

% This is the old version and doesn't seem to match ROMS set_depths.F
%z = (1.0+s) * zeta + s * hc + Cs * (h-hc) ;
%       z(:,:,k)=zeta.*(1.0+s_rho(k)) + hc*s_rho(k) + (h-hc).*Cs_r(k);

%% Reshape to final size
z = reshape(z,endSize);

% Eliminate second dimension if it's one
rank = length(endSize);

if endSize(2)==1
    z = permute(z,[1 3:rank 2]);
end

end