function vslice_example(file,TT)
%
% This is an example for plotting a vertical transect of salinity
%
%Inputs:
% file is a string of the ROMS output (history) file
% TT is the timestep
%
% e.g. pslice_example(file,11)
%      This plots the a vertical transect at timestep 11
%      For the riverplume model, 
%
%
%% Load data

% Path to ROMS history file
%file='ocean_his_005.nc';


% Pull out time and spatial dimensions
time=ncread(file,'ocean_time');
    %Convert time from seconds into days
    time=time/60/60/24;
    % Reference time to first timestep
    time=time-time(1);
y=ncread(file,'y_rho');
x=ncread(file,'x_rho');
    %Convert from m to km
    x=x./1000;
    y=y./1000;
h=ncread(file,'h');
z=roms_depths(file,'rho');

% Pull out the variable of interest
salt=ncread(file,'salt'); 

%%  Plot across-shore transect
figure
clf
set(gcf,'color','w')

set(0,'defaultaxesfontsize',16)
% Plot salinity for timestep TT and across-shore row YY
YY=52;  %choose 120th row of the grid
c_axis=[20 32];        
pcolor(repmat(x(:,YY),[1 size(z,3)]),...
    squeeze(z(:,YY,:,TT)),...
    squeeze(salt(:,YY,:,TT)));
caxis(c_axis); 
colorbar
title(sprintf('Salinity, Model Day %1.2f',time(TT)))
%xlim([5 50])
%ylim([60 190])
xlabel('Across-Shore Distance (km)')
ylabel('Water Depth (m)')
shading flat
set(gca,'color',[.5 .5 .5])
end